summaryrefslogtreecommitdiffstats
path: root/test/test_nat.py
diff options
context:
space:
mode:
authorMatus Fabian <matfabia@cisco.com>2018-08-14 05:14:55 -0700
committerOle Trøan <otroan@employees.org>2018-08-15 07:10:05 +0000
commit8fed4240be68b2b4b4b6c531233044f3f1ac70c4 (patch)
treedc4bd618112f64794c96959e4a351a9e23548477 /test/test_nat.py
parentb11f903ae8824568c5e1bf8312dcf83c7b58b5ee (diff)
NAT64: fix TCP session expire (VPP-1390)
Add missing call of nat64_tcp_session_set_state to set TCP session state. Change-Id: Ifd297ea3ffe20870e1e34a95449b5c9404ec13eb Signed-off-by: Matus Fabian <matfabia@cisco.com>
Diffstat (limited to 'test/test_nat.py')
-rw-r--r--test/test_nat.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/test_nat.py b/test/test_nat.py
index 0d723b0a688..424b92c6e34 100644
--- a/test/test_nat.py
+++ b/test/test_nat.py
@@ -5943,7 +5943,7 @@ class TestNAT64(MethodHolder):
self.nat_addr_n)
self.vapi.nat64_add_del_interface(self.pg0.sw_if_index)
self.vapi.nat64_add_del_interface(self.pg1.sw_if_index, is_inside=0)
- self.vapi.nat64_set_timeouts(icmp=5)
+ self.vapi.nat64_set_timeouts(icmp=5, tcp_trans=5, tcp_est=5)
pkts = self.create_stream_in_ip6(self.pg0, self.pg1)
self.pg0.add_stream(pkts)
@@ -5955,9 +5955,9 @@ class TestNAT64(MethodHolder):
sleep(15)
# ICMP session after timeout
ses_num_after_timeout = self.nat64_get_ses_num()
- self.assertNotEqual(ses_num_before_timeout, ses_num_after_timeout)
+ self.assertEqual(ses_num_before_timeout - ses_num_after_timeout, 2)
def test_icmp_error(self):
""" NAT64 ICMP Error message translation """
@@ -5955,9 +5955,9 @@ class TestNAT64(MethodHolder):
sleep(15)
- # ICMP session after timeout
+ # ICMP and TCP session after timeout
ses_num_after_timeout = self.nat64_get_ses_num()